@@ -94,9 +94,9 @@ sub _build_query ($self) {
 sub _build_exceed_re ($self) {
     my $re;
 
-    push $re->@*, qr/$Pcore::API::Whois::DB->{exceed}->{$self->{host}}/smo if $Pcore::API::Whois::DB->{exceed}->{ $self->{host} };
+    push $re->@*, qr/$Pcore::API::Whois::DB->{exceed}->{$self->{host}}/sm if $Pcore::API::Whois::DB->{exceed}->{ $self->{host} };
 
-    push $re->@*, qr/$Net::Whois::Raw::Data::exceed{$self->{host}}/smo if $Net::Whois::Raw::Data::exceed{ $self->{host} };
+    push $re->@*, qr/$Net::Whois::Raw::Data::exceed{$self->{host}}/sm if $Net::Whois::Raw::Data::exceed{ $self->{host} };
 
     return $re;
 }
